==> 0.2.4%2B5.tar.gz: lib/entity/entity.dart <==
part of viltage;

class Entity {
	int layer;
	int x, y;
	int width, height;
	int activeState = 0;
	int activeAnimation = -1;
	
	List<Collidable> collidables = new List<Collidable>();
  List<VilTAGEAnimation> animations = new List<VilTAGEAnimation>();
	List<State> states = new List<State>();
	  
  Entity(this.x, this.y, this.layer, var screen) {
    if(screen is VilTAGE) screen.getScreen().entities[layer].add(this);
    else screen.entities[layer].add(this);
  	states.add(new State());
  }
  
	render(List<List<CharNode>> charArray) {
		states[activeState].render(x, y, charArray);
	}
  
	update(double delta) { }
	
	updateAnimations(double delta) {
		if(activeAnimation != -1 && activeAnimation < animations.length) {
  	  animations[activeAnimation].update(delta);
      activeState = animations[activeAnimation].sequence[animations[activeAnimation].current];
  	} else activeState = 0;
	}

	remove(var screen) {
		if(screen is VilTAGE) screen.getScreen().entities[layer].remove(this);
		else screen.entities[layer].remove(this);
	}
	
	static testCollision(Entity e1, Entity e2) {
	  for(int i = 0; i < e1.collidables.length; i++) {
	    for(int j = 0; j < e2.collidables.length; j++) {
	      if(Collidable.collides(e1.x, e1.y, e2.x, e2.y, e1.collidables[i], e2.collidables[j])) return true;
	    }
	  }
	  return false;
	}

	static clear(var screenObject) {
	  VilTAGEScreen screen = screenObject;
	  if(screenObject is VilTAGE) screen = screenObject.getScreen();
	  
		for(int i = 0; i < screen.entities.length; i++) {
		  screen.entities[i] = new List<Entity>();
		}
		Entity e = new Entity(0, 0, 0, screen);
		for(int i = 0; i < screen.viltage.width; i++) {
			for(int j = 0; j < screen.viltage.height; j++) {
				e.states[0].createCharNode(i, j, screen.viltage.backgroundChar);
			}
		}
	}
}

==> 0.3.0%2B5.tar.gz: lib/entity/entity.dart <==
part of viltage;

class Entity {
	int layer;
	int x, y;
	int width, height;
	int activeState = 0;
	int activeAnimation = -1;
	
	List<Collidable> collidables = new List<Collidable>();
  List<VilTAGEAnimation> animations = new List<VilTAGEAnimation>();
	List<State> states = new List<State>();
	  
  Entity(this.x, this.y, this.layer, var screen) {
    if(screen is VilTAGE) screen..getScreen().entities[layer].add(this);
    else screen.entities[layer].add(this);
  	states.add(new State());
  }
  
	render(List<List<CharNode>> charArray) {
		states[activeState].render(x, y, charArray);
	}
  
	update(double delta) { }
	
	updateAnimations(double delta) {
		if(activeAnimation != -1 && activeAnimation < animations.length) {
  	  animations[activeAnimation].update(delta);
      activeState = animations[activeAnimation].sequence[animations[activeAnimation].current];
  	} else activeState = 0;
	}

	remove(var screen) {
		if(screen is VilTAGE) screen.getScreen().entities[layer].remove(this);
		else screen.entities[layer].remove(this);
	}
	
	static testCollision(Entity e1, Entity e2) {
	  for(int i = 0; i < e1.collidables.length; i++) {
	    for(int j = 0; j < e2.collidables.length; j++) {
	      if(Collidable.collides(e1.x, e1.y, e2.x, e2.y, e1.collidables[i], e2.collidables[j])) return true;
	    }
	  }
	  return false;
	}

	static clear(var screenObject) {
	  VilTAGEScreen screen = screenObject;
	  if(screenObject is VilTAGE) screen = screenObject.getScreen();
	  
		for(int i = 0; i < screen.entities.length; i++) {
		  screen.entities[i] = new List<Entity>();
		}
		
		Entity e = new Entity(0, 0, 0, screen);
		for(int i = 0; i < screen.viltage.width; i++) {
			for(int j = 0; j < screen.viltage.height; j++) {
				e.states[0].createCharNode(i, j, screen.viltage.backgroundChar);
			}
		}
	}
}
